@@ -7,8 +7,10 @@ plot.biwavelet <-
             bw=FALSE,
             legend.loc=NULL, 
             legend.horiz=FALSE,
-            arrow.size=0.08, arrow.lwd=2, arrow.cutoff=0.9, arrow.col="black", 
-            arrow.nlocs.x=round(length(x$period)/2), arrow.nlocs.y=round(NCOL(x$wave)/2), xlim = NULL, ylim = NULL,
+            arrow.size=0.08, arrow.size.head=0.05, arrow.lwd=2, 
+            arrow.cutoff=0.9, arrow.col="black", 
+            arrow.nlocs.x=round(length(x$period)/2), 
+            arrow.nlocs.y=round(NCOL(x$wave)/2), xlim = NULL, ylim = NULL,
             xaxt = "s", yaxt = "s", form='%Y', ...) {
     if (bw) {
       bw.colors <- colorRampPalette(c("black", "white"))
@@ -26,11 +28,7 @@ plot.biwavelet <-
     type=match.arg(tolower(type), types)
     
     if (type=="power.corr" | type=="power.corr.norm") {
-      if (x$type=="wtc") {
-        x$wave=x$wave.corr
-        x$power=x$power.corr
-      }
-      else if (x$type=="xwt") {
+      if (x$type=="wtc" | x$type=="xwt") {
         x$power=x$power.corr
         x$wave=x$wave.corr
       }
@@ -160,9 +158,12 @@ plot.biwavelet <-
       ## Remove phases where power is weak
       locs=which (zvals < quantile(zvals, arrow.cutoff))
       a[locs]=NA
-      x.ind=seq(max(floor(x$dt/2),1), length(x$t), length=round(min(arrow.nlocs.x, NCOL(x$wave))))
-      y.ind=seq(max(floor(1/2),1), length(x$period), length=round(min(arrow.nlocs.y, length(x$period))))
+      x.ind=seq(max(floor(x$dt/2),1), length(x$t), 
+                length=round(min(arrow.nlocs.x, NCOL(x$wave))))
+      y.ind=seq(max(floor(1/2),1), length(x$period), 
+                length=round(min(arrow.nlocs.y, length(x$period))))
       phase.plot(x$t[x.ind], log2(x$period[y.ind]), a[y.ind, x.ind], 
-                 arrow.size=arrow.size, arrow.lwd=arrow.lwd, arrow.col=arrow.col)    
+                 arrow.size=arrow.size, arrow.size.head=arrow.size.head, 
+                 arrow.lwd=arrow.lwd, arrow.col=arrow.col)    
     }
   }
